@@ -104,7 +104,7 @@ class Block(Base):
                     value = self.info_values.get(iv)
                     param = cfg.get(ATTR_AUTO_SET)
                     new_value = param[0]
-                    if value != new_val:
+                    if value != new_value:
                         time = self.info_values_updated.get(iv)
                         delay = param[1]
                         if time:
@@ -251,13 +251,13 @@ class Block(Base):
                     self._add_device(Relay(self, 2))
                     self._add_device(PowerMeter(self, 1))
                     self._add_device(PowerMeter(self, 2))
-                    self._add_device(Switch(self, 1))
-                    self._add_device(Switch(self, 2))
+                self._add_device(Switch(self, 1))
+                self._add_device(Switch(self, 2))
                 #self._add_device(InfoSensor(self, 'temperature'))
             #todo delayed reload
         #Shelly PLUG'S
         elif self.type == 'SHPLG-1' or self.type == 'SHPLG2-1' or \
-              self.type == 'SHPLG-S':
+              self.type == 'SHPLG-S' or self.type == 'SHPLG-US':
             self._add_device(Relay(self, 0))
             self._add_device(PowerMeter(self, 0))
         elif self.type == 'SHEM':
